==> haskell-hasql-pool-0.5-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-pool
version: 0.5
id: hasql-pool-0.5-EDnO6U3VeK22K9C1GsZpc0
key: hasql-pool-0.5-EDnO6U3VeK22K9C1GsZpc0
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-pool
synopsis: A pool of connections for Hasql
category: Hasql, Database, PostgreSQL
abi: 939206d6d0b742f33d539748d8ae6b66
exposed: True
exposed-modules:
    Hasql.Pool
hidden-modules: Hasql.Pool.Prelude
import-dirs: /usr/lib/ghc-8.4.3/site-local/hasql-pool-0.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/hasql-pool-0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hasql-pool-0.5
hs-libraries: HShasql-pool-0.5-EDnO6U3VeK22K9C1GsZpc0
depends:
    resource-pool-0.2.3.2-H8ME1Uq48cELXvsmcljq2I
    hasql-1.3.0.3-A28fv0W4zWzEGbSWvADfsi time-1.8.0.2
    base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7
abi-depends: resource-pool-0.2.3.2-H8ME1Uq48cELXvsmcljq2I=2c1b1b2a84a776dc63a21d78666174b0
             hasql-1.3.0.3-A28fv0W4zWzEGbSWvADfsi=e5f6a653775305a390983e127c6cfc9b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=6440a7e70ad5450b51ffd7c9c4277ed3
haddock-interfaces: /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html: /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-pool-0.5-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-pool
version: 0.5
id: hasql-pool-0.5-9VjBxFfdpSBFqQk80IAzjz
key: hasql-pool-0.5-9VjBxFfdpSBFqQk80IAzjz
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-pool
synopsis: A pool of connections for Hasql
category: Hasql, Database, PostgreSQL
abi: bd31394615d35ed8a7dec0c37e86748f
exposed: True
exposed-modules:
    Hasql.Pool
hidden-modules: Hasql.Pool.Prelude
import-dirs: /usr/lib/ghc-8.4.3/site-local/hasql-pool-0.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/hasql-pool-0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hasql-pool-0.5
hs-libraries: HShasql-pool-0.5-9VjBxFfdpSBFqQk80IAzjz
depends:
    resource-pool-0.2.3.2-H8ME1Uq48cELXvsmcljq2I
    hasql-1.3.0.3-3V6ciEkju6ZCWOV0dee9Bf time-1.8.0.2
    base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7
abi-depends: resource-pool-0.2.3.2-H8ME1Uq48cELXvsmcljq2I=2c1b1b2a84a776dc63a21d78666174b0
             hasql-1.3.0.3-3V6ciEkju6ZCWOV0dee9Bf=dda637747e543df5db2a7e0b908e51e1
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=6440a7e70ad5450b51ffd7c9c4277ed3
haddock-interfaces: /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html: /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
